<!--
SPDX-FileCopyrightText: Peter Pentchev <roam@ringlet.net>
SPDX-License-Identifier: BSD-2-Clause
-->

# pshlex - API reference

## Commonly-used functions

::: pshlex.join

## Less commonly-used functions

::: pshlex.join_any

## Helper constants

::: pshlex.FEATURES

::: pshlex.VERSION
